@@ -37,7 +37,6 @@
 #ifndef __BANK_H__
 #define __BANK_H__
 
-#include "lister.h"
 #include "account.h"
 
 namespace Ekiga
@@ -49,7 +48,7 @@ namespace Ekiga
    * @{
    */
 
-  class Bank: public virtual GmRefCounted
+  class Bank
   {
   public:
 
@@ -61,7 +60,7 @@ namespace Ekiga
      * @param The callback (the return value means "go on" and allows
      *  stopping the visit)
      */
-    virtual void visit_accounts (sigc::slot1<bool, AccountPtr> visitor) = 0;
+    virtual void visit_accounts (boost::function1<bool, AccountPtr> visitor) const = 0;
 
 
     /** Create the menu for that Bank and its actions.
@@ -74,29 +73,22 @@ namespace Ekiga
 
     /** This signal is emitted when a account has been added.
      */
-    sigc::signal1<void, AccountPtr> account_added;
+    boost::signal1<void, AccountPtr> account_added;
 
     /** This signal is emitted when a account has been removed.
      */
-    sigc::signal1<void, AccountPtr> account_removed;
+    boost::signal1<void, AccountPtr> account_removed;
 
     /** This signal is emitted when a account has been updated.
      */
-    sigc::signal1<void, AccountPtr> account_updated;
-
-    /** This signal is emitted when there is a new registration event
-     * @param: account is the account
-     *         state is the state
-     *         info contains information about the registration status
-     */
-    sigc::signal3<void, Ekiga::AccountPtr, Account::RegistrationState, std::string> registration_event;
+    boost::signal1<void, AccountPtr> account_updated;
 
     /** This chain allows the BankImpl to present forms to the user
      */
-    ChainOfResponsibility<FormRequest*> questions;
+    ChainOfResponsibility<FormRequestPtr> questions;
   };
 
-  typedef gmref_ptr<Bank> BankPtr;
+  typedef boost::shared_ptr<Bank> BankPtr;
 
   /**
    * @}
