@@ -43,7 +43,6 @@
 #include "pcss-endpoint.h"
 
 #include "call-core.h"
-#include "opal-call.h"
 #include "opal-codec-description.h"
 #include "videoinput-info.h"
 
@@ -114,6 +113,7 @@ CallManager::CallManager (Ekiga::ServiceCore & _core)
   forward_on_busy = false;
   unconditional_forward = false;
   stun_enabled = false;
+  auto_answer = false;
 
   // Create video devices
   PVideoDevice::OpenArgs video = GetVideoOutputDevice();
@@ -303,6 +303,18 @@ unsigned CallManager::get_reject_delay () const
 }
 
 
+void CallManager::set_auto_answer (bool enabled)
+{
+  auto_answer = enabled;
+}
+
+
+bool CallManager::get_auto_answer (void) const
+{
+  return auto_answer;
+}
+
+
 const Ekiga::CodecList & CallManager::get_codecs () const
 {
   return codecs;
@@ -386,6 +398,15 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
       }
     }
   }
+  
+
+  // Add the PCSS codecs
+  all_media_formats = pcssEP->GetMediaFormats ();
+  for (int j = 0 ;
+       j < all_media_formats.GetSize () ;
+       j++)
+    order += all_media_formats [j];
+
 
   // Build the mask
   all_media_formats = OpalTranscoder::GetPossibleFormats (pcssEP->GetMediaFormats ());
@@ -396,6 +417,11 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
        i++)
     mask += all_media_formats [i];
 
+  // Blacklist IM protocols for now
+  mask += "T.140";
+  mask += "MSRP";
+  mask += "SIP-IM";
+
   // Update the OpalManager
   SetMediaFormatMask (mask);
   SetMediaFormatOrder (order);
@@ -464,6 +490,17 @@ void CallManager::get_tcp_ports (unsigned & min_port,
   max_port = GetTCPPortMax ();
 }
 
+void
+CallManager::get_rtp_tos (unsigned &tos) const
+{
+  tos = GetRtpIpTypeofService ();
+}
+
+void
+CallManager::set_rtp_tos (unsigned tos)
+{
+  SetRtpIpTypeofService (tos);
+}
 
 void CallManager::set_stun_server (const std::string & server)
 {
@@ -479,9 +516,9 @@ void CallManager::set_stun_enabled (bool enabled)
     // Ready
     new StunDetector (stun_server, *this, queue);
     patience = 20;
-    Ekiga::Runtime::run_in_main (sigc::mem_fun (this, &CallManager::HandleSTUNResult), 1);
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::HandleSTUNResult, this), 1);
   } else
-    ready.emit ();
+    ready ();
 }
 
 
@@ -616,28 +653,41 @@ void CallManager::get_video_options (CallManager::VideoOptions & options) const
   }
 }
 
+void
+CallManager::create_call_in_main (Opal::Call* call)
+{
+  boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
+
+  call_core->add_call (boost::shared_ptr<Opal::Call>(call),
+		       boost::dynamic_pointer_cast<CallManager>(shared_from_this ()));
+}
 
 OpalCall *CallManager::CreateCall (void *uri)
 {
-  gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core"); // FIXME: threaded?
-  gmref_ptr<Opal::Call> call;
+  Opal::Call* call = 0;
 
   if (uri != 0)
-    call = gmref_ptr<Opal::Call> (new Opal::Call (*this, core, (const char *) uri));
+    call = new Opal::Call (*this, core, (const char *) uri);
   else
-    call = gmref_ptr<Opal::Call> (new Opal::Call (*this, core, ""));
-  call_core->add_call (call, gmref_ptr<CallManager>(this));
+    call = new Opal::Call (*this, core, "");
 
-  return call.get ();
+  Ekiga::Runtime::run_in_main (boost::bind (&CallManager::create_call_in_main, this, call));
+
+  return call;
 }
 
+void
+CallManager::emit_removed_in_main (Ekiga::Call* call)
+{
+  call->removed ();
+}
 
 void
 CallManager::DestroyCall (OpalCall *_call)
 {
   Ekiga::Call *call = dynamic_cast<Ekiga::Call *> (_call);
 
-  Ekiga::Runtime::emit_signal_in_main(call->removed);
+  Ekiga::Runtime::run_in_main(boost::bind (&CallManager::emit_removed_in_main, this, call));
 }
 
 
@@ -719,7 +769,7 @@ CallManager::HandleSTUNResult ()
 	   iter != end ();
 	   ++iter)
 	(*iter)->set_listen_port ((*iter)->get_listen_interface ().port);
-      ready.emit ();
+      ready ();
     }
   } else if (patience == 0) {
 
@@ -732,12 +782,11 @@ CallManager::HandleSTUNResult ()
 		       " still use it, but you need to configure your network settings manually.\n\n"
 		       "Please see http://wiki.ekiga.org/index.php/Enable_port_forwarding_manually for"
 		       " instructions"));
-    ready.emit ();
+    ready ();
   } else if (!got_answer) {
 
     patience--;
-    Ekiga::Runtime::run_in_main (sigc::mem_fun (this, &CallManager::HandleSTUNResult),
-				 1);
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::HandleSTUNResult, this), 1);
 
   }
 }
@@ -745,13 +794,12 @@ CallManager::HandleSTUNResult ()
 void
 CallManager::ReportSTUNError (const std::string error)
 {
-  gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core");
+  boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
 
   // notice we're in for an infinite loop if nobody ever reports to the user!
-  if ( !call_core->errors.handle_request (error)) {
+  if ( !call_core->errors (error)) {
 
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &CallManager::ReportSTUNError),
-					     error),
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::ReportSTUNError, this, error),
 				 10);
   }
 }
