@@ -17,7 +17,7 @@
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * Ekiga is licensed under the GPL license and as a special exc_managertion,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
  * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
  * without applying the requirements of the GNU GPL to the OPAL, OpenH323
@@ -53,6 +53,8 @@
 #include "personal-details.h"
 #include "opal-account.h"
 
+#include <ptclib/pxml.h>
+
 namespace Opal {
 
   namespace Sip {
@@ -108,25 +110,20 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
 	manager (_manager),
 	core (_core)
 {
-  gmref_ptr<Ekiga::ChatCore> chat_core = core.get ("chat-core");
-
-  {
-    gmref_ptr<Opal::Bank> smart = core.get ("opal-account-store");
-    smart->reference (); // take a reference in the main thread
-    bank = smart.get ();
-  }
-
+  boost::shared_ptr<Ekiga::ChatCore> chat_core = core.get<Ekiga::ChatCore> ("chat-core");
+  boost::shared_ptr<Opal::Bank> bank = core.get<Opal::Bank> ("opal-account-store");
 
+  auto_answer_call = false;
   protocol_name = "sip";
   uri_prefix = "sip:";
   listen_port = (_listen_port > 0 ? _listen_port : 5060);
 
-  dialect = gmref_ptr<SIP::Dialect>(new SIP::Dialect (core, sigc::mem_fun (this, &Opal::Sip::EndPoint::send_message)));
+  dialect = boost::shared_ptr<SIP::Dialect>(new SIP::Dialect (core, boost::bind (&Opal::Sip::EndPoint::send_message, this, _1, _2)));
   chat_core->add_dialect (dialect);
 
-  bank->account_added.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
-  bank->account_removed.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
-  bank->account_updated.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
+  bank->account_added.connect (boost::bind (&Opal::Sip::EndPoint::on_bank_updated, this, _1));
+  bank->account_removed.connect (boost::bind (&Opal::Sip::EndPoint::on_bank_updated, this, _1));
+  bank->account_updated.connect (boost::bind (&Opal::Sip::EndPoint::on_bank_updated, this, _1));
 
   /* Timeouts */
   SetAckTimeout (PTimeInterval (0, 32));
@@ -153,7 +150,7 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
 
 Opal::Sip::EndPoint::~EndPoint ()
 {
-  bank->unreference (); // leave a reference in the main thread
+  manager.ShutDownEndpoints ();
 }
 
 
@@ -182,6 +179,8 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 {
   bool populated = false;
 
+  boost::shared_ptr<Opal::Bank> bank = core.get<Opal::Bank> ("opal-account-store");
+
   std::list<std::string> uris;
   std::list<std::string> accounts_list;
 
@@ -194,7 +193,7 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 	 it != bank->end ();
 	 it++) {
 
-      if ((*it)->get_protocol_name () == "SIP" && (*it)->is_active ()) {
+      if ((*it)->get_protocol_name () == "SIP" && (*it)->is_enabled ()) {
 
 	std::stringstream uristr;
 	std::string str = uri;
@@ -241,10 +240,10 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 
     if (0 == GetConnectionCount ())
       builder.add_action ("call", call_action.str (),
-                          sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_dial), (*it)));
+                          boost::bind (&Opal::Sip::EndPoint::on_dial, this, (*it)));
     else
       builder.add_action ("transfer", transfer_action.str (),
-                          sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_transfer), (*it)));
+                          boost::bind (&Opal::Sip::EndPoint::on_transfer, this, (*it)));
 
     ita++;
   }
@@ -261,7 +260,7 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
       msg_action << _("Message");
 
     builder.add_action ("message", msg_action.str (),
-                        sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_message), (*it), fullname));
+                        boost::bind (&Opal::Sip::EndPoint::on_message, this, (*it), fullname));
 
     ita++;
   }
@@ -275,7 +274,14 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 void
 Opal::Sip::EndPoint::fetch (const std::string uri)
 {
+  /* this is for the new opal presence api */
+  PSafePtr<OpalPresentity> presentity = manager.AddPresentity (uri);
+  presentity->SetPresenceChangeNotifier (PCREATE_PresenceChangeNotifier(OnPresenceChange));
+  presentity->Open ();
+
+  /* this is for the old opal presence api */
   Subscribe (SIPSubscribe::Presence, 300, uri);
+
   Subscribe (SIPSubscribe::Dialog, 300, uri);
 }
 
@@ -283,7 +289,12 @@ Opal::Sip::EndPoint::fetch (const std::string uri)
 void
 Opal::Sip::EndPoint::unfetch (const std::string uri)
 {
+  /* this is for the new opal presence api */
+  manager.RemovePresentity (uri);
+
+  /* this is for the old opal presence api */
   Subscribe (SIPSubscribe::Presence, 0, uri);
+
   Subscribe (SIPSubscribe::Dialog, 0, uri);
 }
 
@@ -291,14 +302,14 @@ Opal::Sip::EndPoint::unfetch (const std::string uri)
 void
 Opal::Sip::EndPoint::publish (const Ekiga::PersonalDetails & details)
 {
-  std::map<std::string, PString> publishing;
+  std::map<std::string, PString> to_publish;
   std::string hostname = (const char *) PIPSocket::GetHostName ();
   std::string presence = ((Ekiga::PersonalDetails &) (details)).get_presence ();
   std::string status = ((Ekiga::PersonalDetails &) (details)).get_status ();
 
   for (PSafePtr<SIPHandler> handler = activeSIPHandlers.GetFirstHandler(); handler != NULL; ++handler) {
 
-    if (handler->GetMethod() == SIP_PDU::Method_REGISTER) {
+    if (handler->GetMethod() == SIP_PDU::Method_REGISTER && handler->GetState () == SIPHandler::Subscribed) {
 
       PString data;
       std::string to = handler->GetAddressOfRecord ().AsString ().Mid (4);
@@ -329,18 +340,21 @@ Opal::Sip::EndPoint::publish (const Ekiga::PersonalDetails & details)
       data += "</status>\r\n";
 
       data += "<contact priority=\"1\">";
-      data += to; 
+      data += to;
       data += "</contact>\r\n";
 
       data += "</tuple>\r\n";
       data += "</presence>\r\n";
 
-      publishing[to]=data;
+      if (publications[to] != data) {
+        publications[to] = data;
+        to_publish[to] = data;
+      }
     }
   }
 
-  for (std::map<std::string, PString>::const_iterator iter = publishing.begin ();
-       iter != publishing.end ();
+  for (std::map<std::string, PString>::const_iterator iter = to_publish.begin ();
+       iter != to_publish.end ();
        ++iter)
     Publish (iter->first, iter->second, 500); // TODO: allow to change the 500
 }
@@ -352,8 +366,9 @@ Opal::Sip::EndPoint::send_message (const std::string & _uri,
 {
   if (!_uri.empty () && (_uri.find ("sip:") == 0 || _uri.find (':') == string::npos) && !_message.empty ()) {
 
-    SIPEndPoint::Message (_uri, _message);
-
+    PURL fromAddress;
+    PString conversationId;
+    Message (PURL(_uri), "text/plain;charset=UTF-8", _message, fromAddress, conversationId);
     return true;
   }
 
@@ -395,16 +410,14 @@ Opal::Sip::EndPoint::set_dtmf_mode (unsigned mode)
 {
   switch (mode) {
 
-    // SIP Info
-  case 0:
+  case 0:  // RFC2833
+    SetSendUserInputMode (OpalConnection::SendUserInputAsInlineRFC2833);
+    break;
+  case 1:  // SIP Info
     SetSendUserInputMode (OpalConnection::SendUserInputAsTone);
     break;
-
-    // RFC2833
-  case 1:
-    SetSendUserInputMode (OpalConnection::SendUserInputAsProtocolDefault);
-    break;
   default:
+    g_return_if_reached ();
     break;
   }
 }
@@ -413,14 +426,15 @@ Opal::Sip::EndPoint::set_dtmf_mode (unsigned mode)
 unsigned
 Opal::Sip::EndPoint::get_dtmf_mode () const
 {
-  // SIP Info
-  if (GetSendUserInputMode () == OpalConnection::SendUserInputAsTone)
-    return 0;
-
   // RFC2833
   if (GetSendUserInputMode () == OpalConnection::SendUserInputAsInlineRFC2833)
+    return 0;
+
+  // SIP Info
+  if (GetSendUserInputMode () == OpalConnection::SendUserInputAsTone)
     return 1;
 
+  g_return_val_if_reached (1);
   return 1;
 }
 
@@ -576,10 +590,10 @@ Opal::Sip::EndPoint::Register (const std::string username,
     aor << username;
 
   SIPRegister::Params params;
-  params.m_addressOfRecord = aor.str ();
-  params.m_registrarAddress = host_;
+  params.m_addressOfRecord = PString (aor.str ());
+  params.m_registrarAddress = PString (host_);
   if (is_limited)
-    params.m_compatibility = SIPRegister::e_CannotRegisterMultipleContacts;
+    params.m_contactAddress = "%LIMITED";
   params.m_authID = auth_username;
   params.m_password = password;
   params.m_expire = is_enabled ? timeout : 0;
@@ -609,10 +623,7 @@ Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
     Subscribe (SIPSubscribe::MessageSummary, 3600, aor);
 
   /* Signal */
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::registration_event_in_main),
-					   strm.str (),
-					   was_registering ? Ekiga::Account::Registered : Ekiga::Account::Unregistered,
-					   std::string ()));
+  Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::registration_event_in_main, this, strm.str (), was_registering ? Account::Registered : Account::Unregistered, std::string ()));
 }
 
 
@@ -632,43 +643,35 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
 
   switch (r) {
 
-  case SIP_PDU::Failure_BadRequest:
-    info = _("Bad request");
-    break;
-
-  case SIP_PDU::Failure_PaymentRequired:
-    info = _("Payment required");
-    break;
-
-  case SIP_PDU::Failure_UnAuthorised:
-    info = _("Unauthorized");
-    break;
-
-  case SIP_PDU::Failure_Forbidden:
-    info = _("Forbidden");
-    break;
-
-  case SIP_PDU::Failure_RequestTimeout:
-    info = _("Timeout");
-    break;
-
-  case SIP_PDU::Failure_Conflict:
-    info = _("Conflict");
-    break;
-
-  case SIP_PDU::Failure_TemporarilyUnavailable:
-    info = _("Temporarily unavailable");
-    break;
-
-  case SIP_PDU::Failure_NotAcceptable:
-    info = _("Not acceptable");
-    break;
-
+    // all these codes are defined in opal, file include/sip/sippdu.h
   case SIP_PDU::IllegalStatusCode:
     info = _("Illegal status code");
     break;
 
+  case SIP_PDU::Local_TransportError:
+  case SIP_PDU::Local_BadTransportAddress:
+    info = _("Transport error");
+    break;
+
+  case SIP_PDU::Local_Timeout:
+    /* Translators: Host of the remote party is offline, this should
+     * appear when the remote host does not reply in an acceptable time */
+    info = _("Remote party host is offline");
+    break;
+
+  case SIP_PDU::Information_Trying:
+  case SIP_PDU::Information_Ringing:
+  case SIP_PDU::Information_CallForwarded:
+  case SIP_PDU::Information_Queued:
+  case SIP_PDU::Information_Session_Progress:
+  case SIP_PDU::Successful_OK:
+  case SIP_PDU::Successful_Accepted:
+    break;
+
   case SIP_PDU::Redirection_MultipleChoices:
+    /* Translators: the following strings are answers from the SIP server
+     * when the packet it receives has an error, see
+     * http://www.ietf.org/rfc/rfc3261.txt, chapter 21 for more information */
     info = _("Multiple choices");
     break;
 
@@ -688,6 +691,22 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     info = _("Alternative service");
     break;
 
+  case SIP_PDU::Failure_BadRequest:
+    info = _("Bad request");
+    break;
+
+  case SIP_PDU::Failure_UnAuthorised:
+    info = _("Unauthorized");
+    break;
+
+  case SIP_PDU::Failure_PaymentRequired:
+    info = _("Payment required");
+    break;
+
+  case SIP_PDU::Failure_Forbidden:
+    info = _("Forbidden, please check that username and password are correct");
+    break;
+
   case SIP_PDU::Failure_NotFound:
     info = _("Not found");
     break;
@@ -696,10 +715,22 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     info = _("Method not allowed");
     break;
 
+  case SIP_PDU::Failure_NotAcceptable:
+    info = _("Not acceptable");
+    break;
+
   case SIP_PDU::Failure_ProxyAuthenticationRequired:
     info = _("Proxy authentication required");
     break;
 
+  case SIP_PDU::Failure_RequestTimeout:
+    info = _("Timeout");
+    break;
+
+  case SIP_PDU::Failure_Conflict:
+    info = _("Conflict");
+    break;
+
   case SIP_PDU::Failure_LengthRequired:
     info = _("Length required");
     break;
@@ -721,7 +752,10 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     break;
 
   case SIP_PDU::Failure_BadExtension:
-    // Translators : The extension we are trying to register does not exist
+    /* Translators:  The extension we are trying to register does not exist.
+     * Here extension is a specific "phone number", see
+     * http://en.wikipedia.org/wiki/Extension_(telephone)
+     * for more information */
     info = _("Bad extension");
     break;
 
@@ -733,6 +767,10 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     info = _("Interval too brief");
     break;
 
+  case SIP_PDU::Failure_TemporarilyUnavailable:
+    info = _("Temporarily unavailable");
+    break;
+
   case SIP_PDU::Failure_LoopDetected:
     info = _("Loop detected");
     break;
@@ -817,40 +855,22 @@ Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     info = _("Globally not acceptable");
     break;
 
-  case SIP_PDU::Local_TransportError:
-  case SIP_PDU::Local_BadTransportAddress:
-    info = _("Transport error");
-    break;
-
   case SIP_PDU::Failure_TransactionDoesNotExist:
   case SIP_PDU::Failure_Gone:
   case SIP_PDU::MaxStatusCode:
   default:
     info = _("Failed");
-
-  case SIP_PDU::Information_Trying:
-  case SIP_PDU::Information_Ringing:
-  case SIP_PDU::Information_CallForwarded:
-  case SIP_PDU::Information_Queued:
-  case SIP_PDU::Information_Session_Progress:
-  case SIP_PDU::Successful_OK:
-  case SIP_PDU::Successful_Accepted:
-    break;
   }
 
   /* Signal the SIP Endpoint */
   SIPEndPoint::OnRegistrationFailed (strm.str ().c_str (), r, wasRegistering);
 
   /* opal adds a RequestTerminated, and this should not be shown to user,
-  * as a sip code has already been scheduled to be shown
-  */
+   * as a sip code has already been scheduled to be shown
+   */
   if (r != SIP_PDU::Failure_RequestTerminated) {
     /* Signal */
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this,
-							    &Opal::Sip::EndPoint::registration_event_in_main),
-					     strm.str (),
-					     wasRegistering ? Ekiga::Account::RegistrationFailed : Ekiga::Account::UnregistrationFailed,
-					     info));
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::registration_event_in_main, this, strm.str (), wasRegistering ?Account::RegistrationFailed : Account::UnregistrationFailed, info));
   }
 }
 
@@ -866,7 +886,7 @@ Opal::Sip::EndPoint::OnMWIReceived (const PString & party,
     mwi = "0/0";
 
   /* Signal */
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::mwi_received_in_main), party, info));
+  Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::mwi_received_in_main, this, party, mwi));
 }
 
 
@@ -877,6 +897,9 @@ Opal::Sip::EndPoint::OnIncomingConnection (OpalConnection &connection,
 {
   PTRACE (3, "Opal::Sip::EndPoint\tIncoming connection");
 
+  if (!SIPEndPoint::OnIncomingConnection (connection, options, stroptions))
+    return false;
+
   if (!forward_uri.empty () && manager.get_unconditional_forward ())
     connection.ForwardCall (forward_uri);
   else if (manager.GetCallCount () > 1) {
@@ -894,14 +917,40 @@ Opal::Sip::EndPoint::OnIncomingConnection (OpalConnection &connection,
 
       if (!forward_uri.empty () && manager.get_forward_on_no_answer ())
         call->set_no_answer_forward (manager.get_reject_delay (), forward_uri);
-      else
+      else if (auto_answer_call || manager.get_auto_answer ()) {
+        auto_answer_call = false;
+        PTRACE (3, "Opal::Sip::EndPoint\tAuto-Answering incoming connection");
+        call->answer ();
+      }
+      else // Pending
         call->set_reject_delay (manager.get_reject_delay ());
     }
-
-    return SIPEndPoint::OnIncomingConnection (connection, options, stroptions);
   }
 
-  return false;
+  return true;
+}
+
+
+PBoolean
+Opal::Sip::EndPoint::OnReceivedINVITE (OpalTransport& transport,
+                                       SIP_PDU* pdu)
+{
+  if (pdu == NULL)
+    return SIPEndPoint::OnReceivedINVITE (transport, pdu);
+
+  PString str;
+  int appearance;
+
+  pdu->GetMIME ().GetAlertInfo (str, appearance);
+  static const char ringanswer[] = "Ring Answer";
+  PINDEX pos = str.Find (ringanswer);
+
+  if (pos != P_MAX_INDEX) {
+    PTRACE (3, "Opal::Sip::EndPoint\tRing Answer in AlertInfo header, will Auto-Answer incoming connection");
+    auto_answer_call = true;
+  }
+
+  return SIPEndPoint::OnReceivedINVITE (transport, pdu);
 }
 
 
@@ -933,7 +982,7 @@ Opal::Sip::EndPoint::OnReceivedMESSAGE (OpalTransport & transport,
     std::string message_uri = (const char *) uri.AsString ();
     std::string _message = (const char *) pdu.GetEntityBody ();
 
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::push_message_in_main), message_uri, display_name, _message));
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::push_message_in_main, this, message_uri, display_name, _message));
   }
 
   return SIPEndPoint::OnReceivedMESSAGE (transport, pdu);
@@ -949,9 +998,7 @@ Opal::Sip::EndPoint::OnMessageFailed (const SIPURL & messageUrl,
   std::string uri = (const char *) to.AsString ();
   std::string display_name = (const char *) to.GetDisplayName ();
 
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::push_notice_in_main),
-					   uri, display_name,
-					   _("Could not send message")));
+  Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::push_notice_in_main, this, uri, display_name, _("Could not send message")));
 }
 
 
@@ -970,47 +1017,93 @@ Opal::Sip::EndPoint::GetRegisteredPartyName (const SIPURL & aor,
   return GetDefaultRegisteredPartyName (transport);
 }
 
+void
+Opal::Sip::EndPoint::OnPresenceInfoReceived (const SIPPresenceInfo& info)
+{
+  treat_presence_info (info);
+}
 
 void
-Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
-                                             const PString & basic,
-                                             const PString & note)
+Opal::Sip::EndPoint::OnPresenceChange (OpalPresentity& /*presentity*/,
+				       const OpalPresenceInfo& info)
 {
-  PINDEX j;
-  PCaselessString b = basic;
-  PCaselessString s = note;
+  treat_presence_info (info);
+}
 
+void
+Opal::Sip::EndPoint::treat_presence_info (const OpalPresenceInfo& info)
+{
   std::string presence = "unknown";
   std::string status;
 
-  if (!basic.IsEmpty ()) {
+  /* we could do something precise */
+  switch (info.m_state) {
 
-    if (b.Find ("Open") != P_MAX_INDEX)
-      presence = "online";
-    else
-      presence = "offline";
+  case OpalPresenceInfo::InternalError:
+  case OpalPresenceInfo::Forbidden:
+  case OpalPresenceInfo::NoPresence:
+  case OpalPresenceInfo::Unchanged:
+  case OpalPresenceInfo::Unavailable:
+    presence = "offline";
+    break;
+
+  case OpalPresenceInfo::Available:
+  case OpalPresenceInfo::UnknownExtended:
+  case OpalPresenceInfo::Appointment:
+  case OpalPresenceInfo::Away:
+  case OpalPresenceInfo::Breakfast:
+  case OpalPresenceInfo::Busy:
+  case OpalPresenceInfo::Dinner:
+  case OpalPresenceInfo::Holiday:
+  case OpalPresenceInfo::InTransit:
+  case OpalPresenceInfo::LookingForWork:
+  case OpalPresenceInfo::Lunch:
+  case OpalPresenceInfo::Meal:
+  case OpalPresenceInfo::Meeting:
+  case OpalPresenceInfo::OnThePhone:
+  case OpalPresenceInfo::Other:
+  case OpalPresenceInfo::Performance:
+  case OpalPresenceInfo::PermanentAbsence:
+  case OpalPresenceInfo::Playing:
+  case OpalPresenceInfo::Presentation:
+  case OpalPresenceInfo:: Shopping:
+  case OpalPresenceInfo::Sleeping:
+  case OpalPresenceInfo::Spectator:
+  case OpalPresenceInfo::Steering:
+  case OpalPresenceInfo::Travel:
+  case OpalPresenceInfo::TV:
+  case OpalPresenceInfo::Vacation:
+  case OpalPresenceInfo::Working:
+  case OpalPresenceInfo:: Worship:
+    presence = "online";
+    break;
+  default:
+    presence = "offline";
+    break;
   }
 
-  if (!note.IsEmpty ()) {
+  if (!info.m_note.IsEmpty ()) {
 
-    if (s.Find ("Away") != P_MAX_INDEX)
+    PINDEX j;
+    PCaselessString note = info.m_note;
+    if (note.Find ("Away") != P_MAX_INDEX)
       presence = "away";
-    else if (s.Find ("On the phone") != P_MAX_INDEX)
+    else if (note.Find ("On the phone") != P_MAX_INDEX)
       presence = "inacall";
-    else if (s.Find ("Ringing") != P_MAX_INDEX)
+    else if (note.Find ("Ringing") != P_MAX_INDEX)
       presence = "ringing";
-    else if (s.Find ("dnd") != P_MAX_INDEX
-             || s.Find ("Do Not Disturb") != P_MAX_INDEX)
+    else if (note.Find ("dnd") != P_MAX_INDEX
+             || note.Find ("Do Not Disturb") != P_MAX_INDEX)
       presence = "dnd";
 
-    else if (s.Find ("Free For Chat") != P_MAX_INDEX)
+    else if (note.Find ("Free For Chat") != P_MAX_INDEX)
       presence = "freeforchat";
 
-    if ((j = s.Find (" - ")) != P_MAX_INDEX)
-      status = (const char *) note.Mid (j + 3);
+    if ((j = note.Find (" - ")) != P_MAX_INDEX)
+      status = (const char *) info.m_note.Mid (j + 3);
   }
 
-  SIPURL sip_uri = SIPURL (user);
+  SIPURL sip_uri = SIPURL (info.m_entity);
   sip_uri.Sanitise (SIPURL::ExternalURI);
   std::string _uri = sip_uri.AsString ();
   std::string old_presence = presence_infos[_uri].presence;
@@ -1027,7 +1120,7 @@ Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
   if (presence != "unknown" && (old_presence != presence || old_status != status)) {
     presence_infos[_uri].presence = presence;
     presence_infos[_uri].status = status;
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::presence_status_in_main), _uri, presence_infos[_uri].presence, presence_infos[_uri].status));
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::presence_status_in_main, this, _uri, presence_infos[_uri].presence, presence_infos[_uri].status));
   }
 }
 
@@ -1041,6 +1134,8 @@ Opal::Sip::EndPoint::OnDialogInfoReceived (const SIPDialogNotification & info)
   std::string uri = (const char *) info.m_entity;
   PString remote_uri = info.m_remote.m_identity;
   PString remote_display_name = info.m_remote.m_display.IsEmpty () ? remote_uri : info.m_remote.m_display;
+  if (uri.find ("sip:") == string::npos)
+    uri = "sip:" + uri;
 
   switch (info.m_state) {
   case SIPDialogNotification::Proceeding:
@@ -1069,10 +1164,13 @@ Opal::Sip::EndPoint::OnDialogInfoReceived (const SIPDialogNotification & info)
   dialog_infos[uri].presence = presence;
   dialog_infos[uri].status = status;
 
+  if (presence_infos[uri].presence.empty ())
+    presence_infos[uri].presence = "online";
+
   if (_status)
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::presence_status_in_main), uri, dialog_infos[uri].presence, dialog_infos[uri].status));
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::presence_status_in_main, this, uri, dialog_infos[uri].presence, dialog_infos[uri].status));
   else
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::presence_status_in_main), uri, presence_infos[uri].presence, presence_infos[uri].status));
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Sip::EndPoint::presence_status_in_main, this, uri, presence_infos[uri].presence, presence_infos[uri].status));
 }
 
 
@@ -1101,14 +1199,15 @@ void Opal::Sip::EndPoint::on_transfer (std::string uri)
 void
 Opal::Sip::EndPoint::on_bank_updated (Ekiga::AccountPtr /*account*/)
 {
-  bank->visit_accounts (sigc::mem_fun (this, &Opal::Sip::EndPoint::visit_accounts));
+  boost::shared_ptr<Opal::Bank> bank = core.get<Opal::Bank> ("opal-account-store");
+  bank->visit_accounts (boost::bind (&Opal::Sip::EndPoint::visit_accounts, this, _1));
 }
 
 
 bool
 Opal::Sip::EndPoint::visit_accounts (Ekiga::AccountPtr account_)
 {
-  Opal::AccountPtr account = account_;
+  Opal::AccountPtr account = boost::dynamic_pointer_cast<Opal::Account> (account_);
 
   PWaitAndSignal m(aorMutex);
   accounts[account->get_host ()] = account->get_aor ();
@@ -1119,13 +1218,14 @@ Opal::Sip::EndPoint::visit_accounts (Ekiga::AccountPtr account_)
 
 void
 Opal::Sip::EndPoint::registration_event_in_main (const std::string aor,
-						 Ekiga::Account::RegistrationState state,
+						 Opal::Account::RegistrationState state,
 						 const std::string msg)
 {
+  boost::shared_ptr<Opal::Bank> bank = core.get<Opal::Bank> ("opal-account-store");
   AccountPtr account = bank->find_account (aor);
 
-  if (account) 
-    account->registration_event.emit (state, msg);
+  if (account)
+    account->handle_registration_event (state, msg);
 }
 
 
@@ -1134,8 +1234,8 @@ Opal::Sip::EndPoint::presence_status_in_main (std::string uri,
 					      std::string presence,
 					      std::string status)
 {
-  presence_received.emit (uri, presence);
-  status_received.emit (uri, status);
+  presence_received (uri, presence);
+  status_received (uri, status);
 }
 
 void
@@ -1158,10 +1258,11 @@ void
 Opal::Sip::EndPoint::mwi_received_in_main (const std::string aor,
 					   const std::string info)
 {
+  boost::shared_ptr<Opal::Bank> bank = core.get<Opal::Bank> ("opal-account-store");
   AccountPtr account = bank->find_account (aor);
 
   if (account) {
 
-    account->mwi_event.emit (info);
+    account->handle_message_waiting_information (info);
   }
 }
