@@ -61,11 +61,11 @@ namespace Opal {
   namespace Sip {
 
     class EndPoint : public SIPEndPoint,
+		     public Ekiga::Service,
 		     public Ekiga::CallProtocolManager,
 		     public Ekiga::PresenceFetcher,
 		     public Ekiga::PresencePublisher,
 		     public Ekiga::PresentityDecorator,
-		     public Ekiga::AccountSubscriberImpl<Opal::Account>,
 		     public Ekiga::ContactDecorator
     {
       PCLASSINFO(EndPoint, SIPEndPoint);
@@ -87,6 +87,13 @@ namespace Opal {
 
       ~EndPoint ();
 
+      /* Service */
+      const std::string get_name () const
+      { return "opal-sip-endpoint"; }
+
+      const std::string get_description () const
+      { return "\tObject managing SIP objects with the Opal library"; }
+
       /* ContactDecorator and PresentityDecorator */
       bool populate_menu (Ekiga::ContactPtr contact,
 			  const std::string uri,
@@ -153,6 +160,8 @@ namespace Opal {
 		     const std::string auth_username,
 		     const std::string password,
 		     bool is_enabled,
+		     bool is_limited, /* limited registrar = which do not accept
+                                 extra contact addresses, such as private ones*/
 		     unsigned timeout);
 
       void OnRegistered (const PString & aor,
@@ -170,12 +179,19 @@ namespace Opal {
                                  unsigned options,
                                  OpalConnection::StringOptions * stroptions);
 
-      void OnPresenceInfoReceived (const PString & user,
-                                   const PString & basic,
-                                   const PString & note);
+      /* new opal presence api -- doesn't work yet with ekiga.net */
+      PDECLARE_PresenceChangeNotifier (EndPoint, OnPresenceChange);
+
+      /* old opal presence api -- the one which works with ekiga.net */
+      void OnPresenceInfoReceived (const SIPPresenceInfo& info);
+
+      /* common function to treat presence information coming from both opal presence api */
+      void treat_presence_info (const OpalPresenceInfo& info);
 
       void OnDialogInfoReceived (const SIPDialogNotification & info);
 
+      PBoolean OnReceivedINVITE (OpalTransport & transport, SIP_PDU * pdu);
+
       bool OnReceivedMESSAGE (OpalTransport & transport,
                               SIP_PDU & pdu);
 
@@ -193,8 +209,12 @@ namespace Opal {
 		       std::string name);
       void on_transfer (std::string uri);
 
+      void on_bank_updated (Ekiga::AccountPtr account);
+
+      bool visit_accounts (Ekiga::AccountPtr account);
+
       void registration_event_in_main (const std::string aor,
-				       Ekiga::Account::RegistrationState state,
+				       Account::RegistrationState state,
 				       const std::string msg);
 
       void presence_status_in_main (std::string uri,
@@ -215,14 +235,13 @@ namespace Opal {
       PMutex msgDataMutex;
       msgDict msgData;
 
-      CallManager & manager;
+      PMutex aorMutex;
+      std::map<std::string, std::string> accounts;
 
-      PMutex listsMutex;
-      std::list<std::string> to_subscribe_uris;  // List of uris to subscribe
-      std::list<std::string> subscribed_uris;    // List of subscribed uris
-      std::list<std::string> aors;               // List of registered aor
+      CallManager & manager;
       Ekiga::ServiceCore & core;
-      Opal::Bank* bank;
+
+      std::map<std::string, PString> publications;
 
       Ekiga::CallProtocolManager::Interface listen_iface;
 
@@ -232,10 +251,10 @@ namespace Opal {
       std::string outbound_proxy;
 
       unsigned listen_port;
+      bool auto_answer_call;
 
-      gmref_ptr<SIP::Dialect> dialect;
+      boost::shared_ptr<SIP::Dialect> dialect;
 
-      domain_list active_domains;   // List of active domains
       uri_info_map presence_infos;  // List of uri presences
       uri_info_map dialog_infos;    // List of uri dialog informations
     };
