@@ -48,7 +48,7 @@ struct _ChatWindowPrivate
   {}
 
   Ekiga::ChatCore& core;
-  std::list<sigc::connection> connections;
+  std::list<boost::signals::connection> connections;
 
   GtkWidget* notebook;
 };
@@ -61,7 +61,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static GObjectClass* parent_class = NULL;
+G_DEFINE_TYPE (ChatWindow, chat_window, GM_TYPE_WINDOW);
 
 /* helper (declaration) */
 
@@ -76,7 +76,7 @@ static void on_escaped (GtkWidget *widget,
                         gpointer data);
 
 static void on_switch_page (GtkNotebook* notebook,
-			    GtkNotebookPage* page,
+			    gpointer page_,
 			    guint num,
 			    gpointer data);
 
@@ -159,7 +159,7 @@ on_escaped (GtkWidget */*widget*/,
 
 static void
 on_switch_page (G_GNUC_UNUSED GtkNotebook* notebook,
-		G_GNUC_UNUSED GtkNotebookPage* page_,
+		G_GNUC_UNUSED gpointer page_,
 		guint num,
 		gpointer data)
 {
@@ -267,11 +267,11 @@ static bool
 on_dialect_added (ChatWindow* self,
 		  Ekiga::DialectPtr dialect)
 {
-  self->priv->connections.push_front (dialect->simple_chat_added.connect (sigc::hide_return (sigc::bind<0> (sigc::ptr_fun (on_simple_chat_added), self))));
-  self->priv->connections.push_front (dialect->multiple_chat_added.connect (sigc::hide_return (sigc::bind<0> (sigc::ptr_fun (on_multiple_chat_added), self))));
+  self->priv->connections.push_front (dialect->simple_chat_added.connect (boost::bind (&on_simple_chat_added, self, _1)));
+  self->priv->connections.push_front (dialect->multiple_chat_added.connect (boost::bind (&on_multiple_chat_added, self, _1)));
 
-  dialect->visit_simple_chats (sigc::bind<0> (sigc::ptr_fun (on_simple_chat_added), self));
-  dialect->visit_multiple_chats (sigc::bind<0> (sigc::ptr_fun (on_multiple_chat_added), self));
+  dialect->visit_simple_chats (boost::bind (&on_simple_chat_added, self, _1));
+  dialect->visit_multiple_chats (boost::bind (&on_multiple_chat_added, self, _1));
 
   return true;
 }
@@ -319,7 +319,7 @@ on_simple_chat_added (ChatWindow* self,
   g_signal_connect (page, "message-notice-event",
 		    G_CALLBACK (on_message_notice_event), self);
 
-  self->priv->connections.push_front (chat->user_requested.connect (sigc::bind (sigc::ptr_fun (on_some_chat_user_requested), self, page)));
+  self->priv->connections.push_front (chat->user_requested.connect (boost::bind (&on_some_chat_user_requested, self, page)));
 
   return true;
 }
@@ -339,7 +339,7 @@ on_multiple_chat_added (ChatWindow* self,
 				  page, label);
   gtk_widget_show_all (page);
 
-  self->priv->connections.push_front (chat->user_requested.connect (sigc::bind (sigc::ptr_fun (on_some_chat_user_requested), self, page)));
+  self->priv->connections.push_front (chat->user_requested.connect (boost::bind (&on_some_chat_user_requested, self, page)));
 
   return true;
 }
@@ -358,16 +358,6 @@ on_some_chat_user_requested (ChatWindow* self,
 
 /* GObject code */
 
-static void
-chat_window_dispose (GObject* obj)
-{
-  ChatWindow* self = NULL;
-
-  self = CHAT_WINDOW (obj);
-
-  parent_class->dispose (obj);
-}
-
 static void
 chat_window_finalize (GObject* obj)
 {
@@ -375,7 +365,7 @@ chat_window_finalize (GObject* obj)
 
   self = CHAT_WINDOW (obj);
 
-  for (std::list<sigc::connection>::iterator iter
+  for (std::list<boost::signals::connection>::iterator iter
 	 = self->priv->connections.begin ();
        iter != self->priv->connections.end ();
        ++iter)
@@ -384,20 +374,14 @@ chat_window_finalize (GObject* obj)
   delete self->priv;
   self->priv = NULL;
 
-  parent_class->finalize (obj);
+  G_OBJECT_CLASS (chat_window_parent_class)->finalize (obj);
 }
 
 static void
-chat_window_class_init (gpointer g_class,
-			G_GNUC_UNUSED gpointer class_data)
+chat_window_class_init (ChatWindowClass* klass)
 {
-  ChatWindowClass* chat_window_class = NULL;
-  GObjectClass* gobject_class = NULL;
+  GObjectClass* gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = (GObjectClass*) g_type_class_peek_parent (g_class);
-
-  gobject_class = (GObjectClass*) g_class;
-  gobject_class->dispose = chat_window_dispose;
   gobject_class->finalize = chat_window_finalize;
 
   signals[UNREAD_COUNT] =
@@ -418,46 +402,13 @@ chat_window_class_init (gpointer g_class,
 		  NULL, NULL,
 		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  /* FIXME: is it useful? */
-  chat_window_class = (ChatWindowClass*)g_class;
-  chat_window_class->unread_count = NULL;
 }
 
 static void
-chat_window_init (GTypeInstance* instance,
-		  G_GNUC_UNUSED gpointer g_class)
+chat_window_init (ChatWindow* self)
 {
   /* we can't do much here since we get the Chat as reference... */
-  gtk_window_set_title (GTK_WINDOW (instance), _("Chat Window"));
-}
-
-GType
-chat_window_get_type ()
-{
-  static GType result = 0;
-
-  if (result == 0) {
-
-    static const GTypeInfo info = {
-      sizeof (ChatWindowClass),
-      NULL,
-      NULL,
-      chat_window_class_init,
-      NULL,
-      NULL,
-      sizeof (ChatWindow),
-      0,
-      chat_window_init,
-      NULL
-    };
-
-    result = g_type_register_static (GM_WINDOW_TYPE,
-				     "ChatWindow",
-				     &info, (GTypeFlags) 0);
-  }
-
-  return result;
+  gtk_window_set_title (GTK_WINDOW (self), _("Chat Window"));
 }
 
 /* public api */
@@ -491,8 +442,8 @@ chat_window_new (Ekiga::ChatCore& core,
   g_signal_connect (result->priv->notebook, "switch-page",
 		    G_CALLBACK (on_switch_page), result);
 
-  result->priv->connections.push_front (core.dialect_added.connect (sigc::hide_return(sigc::bind<0>(sigc::ptr_fun (on_dialect_added), result))));
-  core.visit_dialects (sigc::bind<0>(sigc::ptr_fun (on_dialect_added), result));
+  result->priv->connections.push_front (core.dialect_added.connect (boost::bind (&on_dialect_added, result, _1)));
+  core.visit_dialects (boost::bind (&on_dialect_added, result, _1));
 
   return (GtkWidget*)result;
 }
