@@ -78,7 +78,7 @@ namespace Ekiga
 
     ~HeapImpl ();
 
-    void visit_presentities (sigc::slot1<bool, PresentityPtr > visitor);
+    void visit_presentities (boost::function1<bool, PresentityPtr > visitor) const;
 
     const_iterator begin () const;
 
@@ -92,9 +92,9 @@ namespace Ekiga
 
     using RefLister<PresentityType>::add_connection;
 
-    void add_presentity (gmref_ptr<PresentityType> presentity);
+    void add_presentity (boost::shared_ptr<PresentityType> presentity);
 
-    void remove_presentity (gmref_ptr<PresentityType> presentity);
+    void remove_presentity (boost::shared_ptr<PresentityType> presentity);
   };
 
 /**
@@ -108,9 +108,9 @@ template<typename PresentityType>
 Ekiga::HeapImpl<PresentityType>::HeapImpl ()
 {
   /* this is signal forwarding */
-  RefLister<PresentityType>::object_added.connect (presentity_added.make_slot ());
-  RefLister<PresentityType>::object_removed.connect (presentity_removed.make_slot ());
-  RefLister<PresentityType>::object_updated.connect (presentity_updated.make_slot ());
+  RefLister<PresentityType>::object_added.connect (boost::ref (presentity_added));
+  RefLister<PresentityType>::object_removed.connect (boost::ref (presentity_removed));
+  RefLister<PresentityType>::object_updated.connect (boost::ref (presentity_updated));
 }
 
 
@@ -121,7 +121,7 @@ Ekiga::HeapImpl<PresentityType>::~HeapImpl ()
 
 template<typename PresentityType>
 void
-Ekiga::HeapImpl<PresentityType>::visit_presentities (sigc::slot1<bool, PresentityPtr > visitor)
+Ekiga::HeapImpl<PresentityType>::visit_presentities (boost::function1<bool, PresentityPtr > visitor) const
 {
   RefLister<PresentityType>::visit_objects (visitor);
 }
@@ -156,16 +156,16 @@ Ekiga::HeapImpl<PresentityType>::end () const
 
 template<typename PresentityType>
 void
-Ekiga::HeapImpl<PresentityType>::add_presentity (gmref_ptr<PresentityType> presentity)
+Ekiga::HeapImpl<PresentityType>::add_presentity (boost::shared_ptr<PresentityType> presentity)
 {
-  presentity->questions.add_handler (questions.make_slot ());
+  presentity->questions.connect (boost::ref (questions));
 
   add_object (presentity);
 }
 
 template<typename PresentityType>
 void
-Ekiga::HeapImpl<PresentityType>::remove_presentity (gmref_ptr<PresentityType> presentity)
+Ekiga::HeapImpl<PresentityType>::remove_presentity (boost::shared_ptr<PresentityType> presentity)
 {
   remove_object (presentity);
 }
