@@ -52,7 +52,7 @@ namespace Ekiga
  */
 
 
-  class PresentityDecorator: public virtual GmRefCounted
+  class PresentityDecorator
   {
   public:
 
@@ -70,7 +70,7 @@ namespace Ekiga
 				MenuBuilder &/*builder*/) = 0;
   };
 
-  class PresenceFetcher: public virtual GmRefCounted
+  class PresenceFetcher
   {
   public:
 
@@ -97,11 +97,11 @@ namespace Ekiga
      * presence information about an uri it was required to handle.
      * The information is given as a pair of strings (uri, data).
      */
-    sigc::signal2<void, std::string, std::string> presence_received;
-    sigc::signal2<void, std::string, std::string> status_received;
+    boost::signal2<void, std::string, std::string> presence_received;
+    boost::signal2<void, std::string, std::string> status_received;
   };
 
-  class PresencePublisher: public virtual GmRefCounted
+  class PresencePublisher
   {
   public:
 
@@ -174,27 +174,27 @@ namespace Ekiga
      * @param The callback (the return value means "go on" and allows
      *  stopping the visit)
      */
-    void visit_clusters (sigc::slot1<bool, ClusterPtr > visitor);
+    void visit_clusters (boost::function1<bool, ClusterPtr > visitor) const;
 
     /** This signal is emitted when an Ekiga::Cluster has been added
      * to the PresenceCore Service.
      */
-    sigc::signal1<void, ClusterPtr > cluster_added;
+    boost::signal1<void, ClusterPtr > cluster_added;
 
     /** Those signals are forwarding the heap_added, heap_updated
      * and heap_removed from the given Cluster.
      *
      */
-    sigc::signal2<void, ClusterPtr , HeapPtr > heap_added;
-    sigc::signal2<void, ClusterPtr , HeapPtr > heap_updated;
-    sigc::signal2<void, ClusterPtr , HeapPtr > heap_removed;
+    boost::signal2<void, ClusterPtr , HeapPtr > heap_added;
+    boost::signal2<void, ClusterPtr , HeapPtr > heap_updated;
+    boost::signal2<void, ClusterPtr , HeapPtr > heap_removed;
 
     /** Those signals are forwarding the presentity_added, presentity_updated
      * and presentity_removed from the given Heap of the given Cluster.
      */
-    sigc::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_added;
-    sigc::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_updated;
-    sigc::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_removed;
+    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_added;
+    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_updated;
+    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_removed;
 
   private:
 
@@ -218,7 +218,7 @@ namespace Ekiga
     /** Adds a decorator to the pool of presentity decorators.
      * @param The presentity decorator.
      */
-    void add_presentity_decorator (gmref_ptr<PresentityDecorator> decorator);
+    void add_presentity_decorator (boost::shared_ptr<PresentityDecorator> decorator);
 
     /** Populates a menu with the actions available on a given uri.
      * @param The uri for which the decoration is needed.
@@ -230,7 +230,7 @@ namespace Ekiga
 
   private:
 
-    std::list<gmref_ptr<PresentityDecorator> > presentity_decorators;
+    std::list<boost::shared_ptr<PresentityDecorator> > presentity_decorators;
 
     /*** API to help presentities get presence ***/
   public:
@@ -238,7 +238,7 @@ namespace Ekiga
     /** Adds a fetcher to the pool of presentce fetchers.
      * @param The presence fetcher.
      */
-    void add_presence_fetcher (gmref_ptr<PresenceFetcher> fetcher);
+    void add_presence_fetcher (boost::shared_ptr<PresenceFetcher> fetcher);
 
     /** Tells the PresenceCore that someone is interested in presence
      * information for the given uri.
@@ -255,12 +255,12 @@ namespace Ekiga
     /** Those signals are emitted whenever information has been received
      * about an uri ; the information is a pair of strings (uri, information).
      */
-    sigc::signal2<void, std::string, std::string> presence_received;
-    sigc::signal2<void, std::string, std::string> status_received;
+    boost::signal2<void, std::string, std::string> presence_received;
+    boost::signal2<void, std::string, std::string> status_received;
 
   private:
 
-    std::list<gmref_ptr<PresenceFetcher> > presence_fetchers;
+    std::list<boost::shared_ptr<PresenceFetcher> > presence_fetchers;
     void on_presence_received (const std::string uri,
 			       const std::string presence);
     void on_status_received (const std::string uri,
@@ -280,18 +280,14 @@ namespace Ekiga
     /* help publishing presence */
   public:
 
-    void add_presence_publisher (gmref_ptr<PresencePublisher> publisher);
+    void add_presence_publisher (boost::shared_ptr<PresencePublisher> publisher);
+
+    void publish (boost::shared_ptr<PersonalDetails> details);
 
   private:
 
-    std::list<gmref_ptr<PresencePublisher> > presence_publishers;
-    void publish (gmref_ptr<PersonalDetails> details);
+    std::list<boost::shared_ptr<PresencePublisher> > presence_publishers;
     void on_personal_details_updated (PersonalDetails &details);
-    void on_registration_event (Ekiga::BankPtr bank,
-				Ekiga::AccountPtr account,
-				Ekiga::Account::RegistrationState state,
-                                std::string info,
-                                gmref_ptr<Ekiga::PersonalDetails> details);
 
     /*** API to control which uri are supported by runtime ***/
   public:
@@ -305,11 +301,11 @@ namespace Ekiga
     /** Adds an uri tester to the PresenceCore
      * @param The tester
      */
-    void add_supported_uri (sigc::slot1<bool,std::string> tester);
+    void add_supported_uri (boost::function1<bool,std::string> tester);
 
   private:
 
-    std::set<sigc::slot1<bool, std::string> > uri_testers;
+    std::list<boost::function1<bool, std::string> > uri_testers;
 
     /*** Misc ***/
   public:
@@ -321,9 +317,9 @@ namespace Ekiga
 
     /** This chain allows the PresenceCore to present forms to the user
      */
-    ChainOfResponsibility<FormRequest*> questions;
+    ChainOfResponsibility<FormRequestPtr> questions;
 
-    std::list<sigc::connection> conns;
+    std::list<boost::signals::connection> conns;
   };
 
 /**
