@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2007 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,9 +82,19 @@ struct xFormatsentry {
   {"RGBA",   1, 0, LSBFirst,     0x000000FF, 0x0000FF00, 0x00FF0000},  //RGBA *
   {"BGR32",  1, 4, MSBFirst,     0x0000FF00, 0x00FF0000, 0xFF000000},  //BGRA
   {"BGRA",   1, 0, LSBFirst,     0x00FF0000, 0x0000FF00, 0x000000FF},  //BGRA *
+  {"RGB16", 16, 2, LSBFirst,     0x0000F800, 0x000007E0, 0x0000001F},  //RGB16
   {NULL, 0, 0, 0, 0, 0, 0}
 };
 
+#ifdef HAVE_SHM
+bool XWindow::_shmError = false;
+
+static void catchXShmError(Display * , XErrorEvent * )
+{
+  XWindow::_shmError = true;
+}
+#endif
+
 XWindow::XWindow()
 {
   // initialize class variables
@@ -116,7 +126,6 @@ XWindow::XWindow()
    snprintf (_colorFormat, sizeof(_colorFormat), "NONE");
   _planes = 0;
   _colorConverter = NULL;
-  _frameBuffer = NULL;
 
 #ifdef HAVE_SHM
   _XShmInfo.shmaddr = NULL;
@@ -156,6 +165,7 @@ XWindow::~XWindow()
 
   if (_XWindow) {
 
+    PTRACE(4, "X11\tUnmapping and destroying Window with ID " << _XWindow);
     XUnmapWindow (_display, _XWindow);
     XDestroyWindow (_display, _XWindow);
     XFlush (_display);
@@ -165,9 +175,6 @@ XWindow::~XWindow()
 
   if (_colorConverter)
     delete (_colorConverter);
-
-  if (_frameBuffer)
-    free (_frameBuffer);
 }
 
 
@@ -190,8 +197,9 @@ XWindow::Init (Display* dp,
   PTRACE(4, "X11\tInitiasing new X11 window with " << windowWidth << "x" << windowHeight << " at " << x << "," << y);
   XLockDisplay (_display);
 
-  if (PTrace::CanTrace (4)) 
-    DumpVisuals();
+#if PTRACING
+  DumpVisuals();
+#endif
 
   if (!CreateAtomsAndWindow(gc, x, y, windowWidth, windowHeight)) {
     XUnlockDisplay(_display);
@@ -263,7 +271,7 @@ XWindow::Init (Display* dp,
   if (!_colorConverter)
     return 0;
 
-  _frameBuffer = (uint8_t*) malloc (_imageWidth * _imageHeight * _planes);
+  _frameBuffer = boost::shared_ptr<void> (malloc (_imageWidth * _imageHeight * _planes), free);
 
   // detect the window manager type
   _wmType = GetWMType ();
@@ -292,7 +300,7 @@ XWindow::PutFrame (uint8_t* frame,
   if ((_state.curWidth != _XImage->width) || (_state.curHeight!=_XImage->height))
     CreateXImage(_state.curWidth, _state.curHeight);
 
-  _colorConverter->Convert((BYTE*)frame, (BYTE*)_frameBuffer);
+  _colorConverter->Convert((BYTE*)frame, (BYTE*)_frameBuffer.get ());
 
   pixops_scale ((guchar*) _XImage->data,
                  0,0,
@@ -301,7 +309,7 @@ XWindow::PutFrame (uint8_t* frame,
                  _planes,                   //dest_channels,
                  FALSE,                     //dest_has_alpha,
 
-                 (const guchar*) _frameBuffer,
+		(const guchar*) _frameBuffer.get (),
                  width,
                  height,
                  width * _planes,           //src_rowstride
@@ -454,7 +462,7 @@ void
 XWindow::Sync()
 {
   XLockDisplay(_display);
-  XSync (_display, false);
+  XSync (_display, False);
   XUnlockDisplay(_display);
 }
 
@@ -537,7 +545,7 @@ XWindow::ToggleFullscreen ()
   XLockDisplay (_display);
   XMapRaised (_display, _XWindow);
   XRaiseWindow (_display, _XWindow);
-  XFlush (_display);
+  XSync (_display, False);
   XUnlockDisplay (_display);
 
   _state.fullscreen = !_state.fullscreen;
@@ -596,7 +604,7 @@ XWindow::GetWindow (int *x,
   SetDecoration (false);
 
   XLockDisplay (_display);
-  XSync (_display,false); 
+  XSync (_display, False); 
   XGetGeometry (_display, _XWindow, &root, &oldx, &oldy, windowWidth, windowHeight, &ud, &ud);
   XTranslateCoordinates (_display, _XWindow, root, oldx, oldy, x, y, &_dw);
   XUnlockDisplay (_display);
@@ -625,7 +633,7 @@ XWindow::CreateAtomsAndWindow(GC gc,
   XA_NET_WM_STATE_STAYS_ON_TOP = XInternAtom (_display, "_NET_WM_STATE_STAYS_ON_TOP", False);
   XA_NET_WM_STATE_BELOW = XInternAtom (_display, "_NET_WM_STATE_BELOW", False);
 
-  XSync (_display, false);
+  XSync (_display, False);
 
   if (!checkDepth()) 
     return false;
@@ -1014,6 +1022,17 @@ bool XWindow::checkDepth ()
       }
     }
   }
+  else if (xwattributes.depth == 16) {
+    _depth = 16;
+    if (!XMatchVisualInfo (_display, DefaultScreen (_display), _depth, TrueColor, &_XVInfo)) {
+      PTRACE(4, "X11\tCould not find visual with colordepth of " << _depth  << " bits per pixel");
+      _depth = 24;
+      if (!XMatchVisualInfo (_display, DefaultScreen (_display), _depth, TrueColor, &_XVInfo)) {
+        PTRACE(1, "X11\tCould neither find visual with colordepth of 16 bits per pixel nor with 24 bits per pixel");
+        return false;
+      }
+    }
+  }
   else {
     _depth = 24;
     if (!XMatchVisualInfo (_display, DefaultScreen (_display), _depth, TrueColor, &_XVInfo)) {
@@ -1065,18 +1084,26 @@ void XWindow::ShmAttach(int imageWidth, int imageHeight)
     _XShmInfo.readOnly = False;
 
     // Attaching the shared memory to the display
-    if (!XShmAttach (_display, &_XShmInfo)) {
+    XErrorHandler oldHandler = XSetErrorHandler((XErrorHandler) catchXShmError);
+    Status status = XShmAttach (_display, &_XShmInfo);
+    XSync(_display, False);
+    XSetErrorHandler((XErrorHandler) oldHandler);
+
+    if ( (status != True) || (_shmError) ) {
       XDestroyImage(_XImage);
       _XImage = NULL;
-      if (_XShmInfo.shmaddr != ((char *) -1))
+      if (_XShmInfo.shmaddr != ((char *) -1)) {
         shmdt(_XShmInfo.shmaddr);
+      }
       PTRACE(1, "X11\t  XShmAttach failed");
+      if ( (status == True) && (_shmError) ) {
+        PTRACE(1, "X11\t  X server supports SHM but apparently we are remotely connected...");
+      }
       _useShm = false;
     } 
   } 
 
   if (_useShm) {
-    XSync(_display, False);
     shmctl(_XShmInfo.shmid, IPC_RMID, 0);
   }
 }
@@ -1144,10 +1171,10 @@ XWindow::DumpVisuals()
     if (visuals != NULL) {
         for (i = 0; i < nbVisuals; i++) {
             PTRACE(4, "X11\tVisual #"  << i << " ID: " << visuals[i].visualid
-                       << " Class: "   << visuals[i].c_class  
+                       << " Class: "   << visuals[i].c_class
                        << " BPRGB: "     << visuals[i].bits_per_rgb
                        << " Depth: "   << visuals[i].depth << std::hex
-                       << " Red: 0x"   << visuals[i].red_mask 
+                       << " Red: 0x"   << visuals[i].red_mask
                        << " Green: 0x" << visuals[i].green_mask
                        << " Blue 0x"   << visuals[i].blue_mask << std::dec);
         }
