@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,14 +45,11 @@ G_BEGIN_DECLS
  */
 void gm_open_uri (const gchar *uri);
 
-/* DESCRIPTION  : safely create an unknown directory
- * BEHAVIOR     : creates a dir with all non-existing parents
- * PRE          : a non-NULL directory, and a mode specified
- *                (glib/POSIX S_I* values for filemodes)
- */
 
-gboolean gm_mkdir_with_parents (const gchar *pathname,
-			         int mode);
+/*!\fm gm_string_gslist_remove_dups (GSlist*)
+ * \brief remove dups in a GSList of strings, return the new list start
+ */
+GSList *gm_string_gslist_remove_dups (GSList *origlist);
 
 
 G_END_DECLS
