@@ -33,7 +33,7 @@
  *   copyright            : (C) 2000-2008 by Damien Sandras
  *                          (C) 2008 by Steve Frécinaux
  *   description          : This file contains all the functions needed to
- *                          build the druid.
+ *                          build the assistant.
  */
 
 #include <glib/gi18n.h>
@@ -44,9 +44,9 @@
 
 #include "ekiga.h"
 #include "gmconf.h"
-#include "misc.h"
 #include "toolbox/toolbox.h"
 #include "assistant.h"
+#include "default_devices.h"
 
 #include "opal-bank.h"
 #include "videoinput-core.h"
@@ -59,6 +59,10 @@ G_DEFINE_TYPE (EkigaAssistant, ekiga_assistant, GTK_TYPE_ASSISTANT);
 struct _EkigaAssistantPrivate
 {
   Ekiga::ServiceCore *core;
+  boost::shared_ptr<Ekiga::VideoInputCore> videoinput_core;
+  boost::shared_ptr<Ekiga::AudioInputCore> audioinput_core;
+  boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core;
+  boost::shared_ptr<Opal::Bank> bank;
   GdkPixbuf *icon;
 
   GtkWidget *welcome_page;
@@ -91,10 +95,10 @@ struct _EkigaAssistantPrivate
   gint last_active_page;
 
   GtkListStore *summary_model;
-  std::vector<sigc::connection> connections;
+  std::vector<boost::signals::connection> connections;
 };
 
-/* presenting the network connectoin type to the user */
+/* presenting the network connection type to the user */
 enum {
   CNX_LABEL_COLUMN,
   CNX_CODE_COLUMN
@@ -141,17 +145,14 @@ set_current_page_complete (GtkAssistant *assistant,
   gtk_assistant_set_page_complete (assistant, current_page, complete);
 }
 
-void 
-get_audiooutput_devices_list (Ekiga::ServiceCore *core,
-                              std::vector<std::string> & device_list);
-void 
-get_audioinput_devices_list (Ekiga::ServiceCore *core,
-                             std::vector<std::string> & device_list);
-void 
-get_videoinput_devices_list (Ekiga::ServiceCore *core,
-                             std::vector<std::string> & device_list);
+static void get_audiooutput_devices_list (boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core,
+					  std::vector<std::string> & device_list);
+static void get_audioinput_devices_list (boost::shared_ptr<Ekiga::AudioInputCore> audioinput_core,
+					 std::vector<std::string> & device_list);
+static void get_videoinput_devices_list (boost::shared_ptr<Ekiga::VideoInputCore> videoinput_core,
+					 std::vector<std::string> & device_list);
 
-gchar**
+static gchar**
 convert_string_list (const std::vector<std::string> & list);
 
 static void
@@ -178,7 +179,7 @@ update_combo_box (GtkComboBox         *combo_box,
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                         0, options [i],
-                        1, true, 
+                        1, true,
                         -1);
   }
 
@@ -251,7 +252,7 @@ remove_combo_box (GtkComboBox         *combo_box,
       if (g_ascii_strcasecmp  (value_string, option) == 0) {
 
         if (cpt == active) {
-          gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+          gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                               1, FALSE,
                               -1);
         }
@@ -268,47 +269,66 @@ remove_combo_box (GtkComboBox         *combo_box,
   }
 }
 
-void on_videoinput_device_added_cb (const Ekiga::VideoInputDevice & device, bool, EkigaAssistant *assistant)
+static void
+on_videoinput_device_added_cb (const Ekiga::VideoInputDevice& device,
+			       bool,
+			       EkigaAssistant* assistant)
 {
   std::string device_string = device.GetString();
   add_combo_box (GTK_COMBO_BOX (assistant->priv->video_device), device_string.c_str());
 }
 
-void on_videoinput_device_removed_cb (const Ekiga::VideoInputDevice & device, bool,  EkigaAssistant *assistant)
+static void
+on_videoinput_device_removed_cb (const Ekiga::VideoInputDevice& device,
+				 bool,
+				 EkigaAssistant* assistant)
 {
   std::string device_string = device.GetString();
   remove_combo_box (GTK_COMBO_BOX (assistant->priv->video_device),  device_string.c_str());
 }
 
-void on_audioinput_device_added_cb (const Ekiga::AudioInputDevice & device, bool, EkigaAssistant *assistant)
+static void
+on_audioinput_device_added_cb (const Ekiga::AudioInputDevice& device,
+			       bool,
+			       EkigaAssistant* assistant)
 {
   std::string device_string = device.GetString();
   add_combo_box (GTK_COMBO_BOX (assistant->priv->audio_recorder), device_string.c_str());
 }
 
-void on_audioinput_device_removed_cb (const Ekiga::AudioInputDevice & device, bool, EkigaAssistant *assistant)
+static void
+on_audioinput_device_removed_cb (const Ekiga::AudioInputDevice& device,
+				 bool,
+				 EkigaAssistant* assistant)
 {
   std::string device_string = device.GetString();
   remove_combo_box (GTK_COMBO_BOX (assistant->priv->audio_recorder),  device_string.c_str());
 }
 
-void on_audiooutput_device_added_cb (const Ekiga::AudioOutputDevice & device, bool, EkigaAssistant *assistant)
+static void
+on_audiooutput_device_added_cb (const Ekiga::AudioOutputDevice& device,
+				bool,
+				EkigaAssistant *assistant)
 {
   std::string device_string = device.GetString();
   add_combo_box (GTK_COMBO_BOX (assistant->priv->audio_player), device_string.c_str());
   add_combo_box (GTK_COMBO_BOX (assistant->priv->audio_ringer), device_string.c_str());
 }
 
-void on_audiooutput_device_removed_cb (const Ekiga::AudioOutputDevice & device, bool, EkigaAssistant *assistant)
+static void
+on_audiooutput_device_removed_cb (const Ekiga::AudioOutputDevice& device,
+				  bool,
+				  EkigaAssistant* assistant)
 {
   std::string device_string = device.GetString();
   remove_combo_box (GTK_COMBO_BOX (assistant->priv->audio_player),  device_string.c_str());
   remove_combo_box (GTK_COMBO_BOX (assistant->priv->audio_ringer),  device_string.c_str());
 }
 
-static void kind_of_net_changed_nt (G_GNUC_UNUSED gpointer id,
-                                         GmConfEntry *, 
-                                         gpointer)
+static void
+kind_of_net_changed_nt (G_GNUC_UNUSED gpointer id,
+			GmConfEntry *,
+			gpointer)
 {
   gm_conf_set_int (GENERAL_KEY "kind_of_net", NET_CUSTOM);
 }
@@ -371,7 +391,7 @@ create_personal_data_page (EkigaAssistant *assistant)
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
-  g_signal_connect (G_OBJECT (assistant->priv->name), "changed",
+  g_signal_connect (assistant->priv->name, "changed",
                     G_CALLBACK (name_changed_cb), assistant);
 
   assistant->priv->personal_data_page = vbox;
@@ -431,7 +451,7 @@ ekiga_out_new_clicked_cb (G_GNUC_UNUSED GtkWidget *widget,
 
   if (account == NULL || password == NULL)
     return; /* no account configured yet */
-  
+
   gm_open_uri ("https://www.diamondcard.us/exec/voip-login?act=sgn&spo=ekiga");
 }
 
@@ -454,7 +474,7 @@ ekiga_out_recharge_clicked_cb (G_GNUC_UNUSED GtkWidget *widget,
 
   if (account == NULL || password == NULL)
     return; /* no account configured yet */
-  
+
   url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=rch&spo=ekiga", account, password);
   gm_open_uri (url);
   g_free (url);
@@ -479,7 +499,7 @@ ekiga_out_history_balance_clicked_cb (G_GNUC_UNUSED GtkWidget *widget,
 
   if (account == NULL || password == NULL)
     return; /* no account configured yet */
-  
+
   url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=bh&spo=ekiga", account, password);
   gm_open_uri (url);
   g_free (url);
@@ -504,7 +524,7 @@ ekiga_out_history_calls_clicked_cb (G_GNUC_UNUSED GtkWidget *widget,
 
   if (account == NULL || password == NULL)
     return; /* no account configured yet */
-  
+
   url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=ch&spo=ekiga", account, password);
   gm_open_uri (url);
   g_free (url);
@@ -624,8 +644,7 @@ create_ekiga_net_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_net_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::AccountPtr account = bank->find_account ("ekiga.net");
+  Opal::AccountPtr account = assistant->priv->bank->find_account ("ekiga.net");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->username), account->get_username ().c_str ());
@@ -641,18 +660,17 @@ prepare_ekiga_net_page (EkigaAssistant *assistant)
 static void
 apply_ekiga_net_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::AccountPtr account = bank->find_account ("ekiga.net");
+  Opal::AccountPtr account = assistant->priv->bank->find_account ("ekiga.net");
   bool new_account = !account;
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_net))) {
 	if (new_account)
-	  bank->new_account (Opal::Account::Ekiga,
-			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
-			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
+	  assistant->priv->bank->new_account (Opal::Account::Ekiga,
+					      gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
+					      gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
-											gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
+						gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
   }
 }
 
@@ -737,7 +755,7 @@ create_ekiga_out_page (EkigaAssistant *assistant)
   button = gtk_button_new ();
   label = gtk_label_new (NULL);
   text = g_strdup_printf ("<span foreground=\"blue\"><u>%s</u></span>",
-			 _("Consult the calls history"));
+			 _("Consult the call history"));
   gtk_label_set_markup (GTK_LABEL (label), text);
   g_free (text);
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
@@ -768,8 +786,7 @@ create_ekiga_out_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_out_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Opal::Bank> account_core = assistant->priv->core->get ("opal-account-store");
-  Opal::AccountPtr account = account_core->find_account ("sip.diamondcard.us");
+  Opal::AccountPtr account = assistant->priv->bank->find_account ("sip.diamondcard.us");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->dusername), account->get_username ().c_str ());
@@ -786,15 +803,14 @@ static void
 apply_ekiga_out_page (EkigaAssistant *assistant)
 {
   /* Some specific Opal stuff for the Ekiga.net account */
-  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::AccountPtr account = bank->find_account ("sip.diamondcard.us");
+  Opal::AccountPtr account = assistant->priv->bank->find_account ("sip.diamondcard.us");
   bool new_account = !account;
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_out))) {
 	if (new_account)
-	  bank->new_account (Opal::Account::DiamondCard,
-			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
-			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
+	  assistant->priv->bank->new_account (Opal::Account::DiamondCard,
+					      gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
+					      gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
 						gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
@@ -949,7 +965,7 @@ create_audio_devices_page (EkigaAssistant *assistant)
   GtkWidget *label;
 
   GtkCellRenderer *renderer;
-  
+
   gchar *text;
 
   vbox = create_page (assistant, _("Audio Devices"), GTK_ASSISTANT_PAGE_CONTENT);
@@ -966,8 +982,8 @@ create_audio_devices_page (EkigaAssistant *assistant)
                                   "text", 0,
                                   "sensitive", 1,
                                   NULL);
-  g_object_set (G_OBJECT (renderer), 
-                "ellipsize-set", TRUE, 
+  g_object_set (G_OBJECT (renderer),
+                "ellipsize-set", TRUE,
                 "ellipsize", PANGO_ELLIPSIZE_END, 
                 "width-chars", 45, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_ringer);
@@ -997,9 +1013,9 @@ create_audio_devices_page (EkigaAssistant *assistant)
                                   "text", 0,
                                   "sensitive", 1,
                                   NULL);
-  g_object_set (G_OBJECT (renderer), 
-                "ellipsize-set", TRUE, 
-                "ellipsize", PANGO_ELLIPSIZE_END, 
+  g_object_set (G_OBJECT (renderer),
+                "ellipsize-set", TRUE,
+                "ellipsize", PANGO_ELLIPSIZE_END,
                 "width-chars", 45, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_player);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->audio_player, FALSE, FALSE, 0);
@@ -1028,9 +1044,9 @@ create_audio_devices_page (EkigaAssistant *assistant)
                                   "text", 0,
                                   "sensitive", 1,
                                   NULL);
-  g_object_set (G_OBJECT (renderer), 
-                "ellipsize-set", TRUE, 
-                "ellipsize", PANGO_ELLIPSIZE_END, 
+  g_object_set (G_OBJECT (renderer),
+                "ellipsize-set", TRUE,
+                "ellipsize", PANGO_ELLIPSIZE_END,
                 "width-chars", 45, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_recorder);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->audio_recorder, FALSE, FALSE, 0);
@@ -1063,15 +1079,15 @@ prepare_audio_devices_page (EkigaAssistant *assistant)
 
   ringer = gm_conf_get_string (SOUND_EVENTS_KEY "output_device");
   if (ringer == NULL || !ringer[0])
-    ringer = g_strdup (get_default_audio_device_name ());
+    ringer = g_strdup (DEFAULT_AUDIO_DEVICE_NAME);
 
   player = gm_conf_get_string (AUDIO_DEVICES_KEY "output_device");
   if (player == NULL || !player[0])
-    player = g_strdup (get_default_audio_device_name ());
+    player = g_strdup (DEFAULT_AUDIO_DEVICE_NAME);
 
   recorder = gm_conf_get_string (AUDIO_DEVICES_KEY "input_device");
   if (recorder == NULL || !recorder[0])
-    recorder = g_strdup (get_default_audio_device_name ());
+    recorder = g_strdup (DEFAULT_AUDIO_DEVICE_NAME);
 
   /* FIXME: We should use DetectDevices, however DetectDevices
    * works only for the currently selected audio and video plugins,
@@ -1079,14 +1095,14 @@ prepare_audio_devices_page (EkigaAssistant *assistant)
    */
   std::vector <std::string> device_list;
 
-  get_audiooutput_devices_list (assistant->priv->core, device_list);
+  get_audiooutput_devices_list (assistant->priv->audiooutput_core, device_list);
   array = convert_string_list(device_list);
   update_combo_box (GTK_COMBO_BOX (assistant->priv->audio_ringer), array, ringer);
   update_combo_box (GTK_COMBO_BOX (assistant->priv->audio_player), array, player);
   g_free (array);
 
 
-  get_audioinput_devices_list (assistant->priv->core, device_list);
+  get_audioinput_devices_list (assistant->priv->audioinput_core, device_list);
   array = convert_string_list(device_list);
   update_combo_box (GTK_COMBO_BOX (assistant->priv->audio_recorder), array, recorder);
   g_free (array);
@@ -1136,7 +1152,7 @@ create_video_devices_page (EkigaAssistant *assistant)
   GtkWidget *label;
   gchar *text;
 
-  vbox = create_page (assistant, _("Video input device"), GTK_ASSISTANT_PAGE_CONTENT);
+  vbox = create_page (assistant, _("Video Input Device"), GTK_ASSISTANT_PAGE_CONTENT);
 
   label = gtk_label_new (_("Please choose your video input device:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -1150,9 +1166,9 @@ create_video_devices_page (EkigaAssistant *assistant)
                                   "text", 0,
                                   "sensitive", 1,
                                   NULL);
-  g_object_set (G_OBJECT (renderer), 
-                "ellipsize-set", TRUE, 
-                "ellipsize", PANGO_ELLIPSIZE_END, 
+  g_object_set (G_OBJECT (renderer),
+                "ellipsize-set", TRUE,
+                "ellipsize", PANGO_ELLIPSIZE_END,
                 "width-chars", 45, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->video_device);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->video_device, FALSE, FALSE, 0);
@@ -1177,7 +1193,7 @@ prepare_video_devices_page (EkigaAssistant *assistant)
   gchar** array;
   gchar* current_plugin;
 
-  get_videoinput_devices_list (assistant->priv->core, device_list);
+  get_videoinput_devices_list (assistant->priv->videoinput_core, device_list);
   array = convert_string_list (device_list);
   current_plugin = gm_conf_get_string (VIDEO_DEVICES_KEY "input_device");
   if (current_plugin == NULL || !current_plugin[0]) {
@@ -1208,16 +1224,14 @@ apply_video_devices_page (EkigaAssistant *assistant)
 
 
 // FIXME: duplicate to gm_prefs_window_get_video_devices_list
-void 
-get_audiooutput_devices_list (Ekiga::ServiceCore *core,
+static void
+get_audiooutput_devices_list (boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core,
                               std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-    = core->get ("audiooutput-core");
   std::vector <Ekiga::AudioOutputDevice> devices;
 
   device_list.clear();
-  audiooutput_core->get_devices(devices);
+  audiooutput_core->get_devices (devices);
 
   for (std::vector<Ekiga::AudioOutputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
@@ -1232,16 +1246,14 @@ get_audiooutput_devices_list (Ekiga::ServiceCore *core,
 }
 
 
-void 
-get_audioinput_devices_list (Ekiga::ServiceCore *core,
+static void
+get_audioinput_devices_list (boost::shared_ptr<Ekiga::AudioInputCore> audioinput_core,
                              std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
-    = core->get ("audioinput-core");
   std::vector <Ekiga::AudioInputDevice> devices;
 
   device_list.clear();
-  audioinput_core->get_devices(devices);
+  audioinput_core->get_devices (devices);
 
   for (std::vector<Ekiga::AudioInputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
@@ -1256,16 +1268,14 @@ get_audioinput_devices_list (Ekiga::ServiceCore *core,
 }
 
 
-void 
-get_videoinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+static void
+get_videoinput_devices_list (boost::shared_ptr<Ekiga::VideoInputCore> videoinput_core,
+			     std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
-    = core->get ("videoinput-core");
   std::vector<Ekiga::VideoInputDevice> devices;
 
   device_list.clear();
-  videoinput_core->get_devices(devices);
+  videoinput_core->get_devices (devices);
 
   for (std::vector<Ekiga::VideoInputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
@@ -1281,7 +1291,7 @@ get_videoinput_devices_list (Ekiga::ServiceCore *core,
 
 
 // FIXME: duplicate to gm_prefs_window_convert_string_list
-gchar**
+static gchar**
 convert_string_list (const std::vector<std::string> & list)
 {
   gchar **array = NULL;
@@ -1351,7 +1361,7 @@ create_summary_page (EkigaAssistant *assistant)
 }
 
 
-static void 
+static void
 prepare_summary_page (EkigaAssistant *assistant)
 {
   GtkListStore *model = assistant->priv->summary_model;
@@ -1537,8 +1547,6 @@ ekiga_assistant_apply (GtkAssistant *gtkassistant)
 {
   EkigaAssistant *assistant = EKIGA_ASSISTANT (gtkassistant);
 
-  GtkWidget *main_window;
-
   apply_personal_data_page (assistant);
   apply_ekiga_net_page (assistant);
   apply_ekiga_out_page (assistant);
@@ -1546,25 +1554,19 @@ ekiga_assistant_apply (GtkAssistant *gtkassistant)
   apply_audio_devices_page (assistant);
   apply_video_devices_page (assistant);
 
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-
-  /* Hide the druid and show the main Ekiga window */
+  /* Hide the assistant and show the main Ekiga window */
   gtk_widget_hide (GTK_WIDGET (assistant));
   gtk_assistant_set_current_page (gtkassistant, 0);
-  gtk_widget_show (main_window);
+  gtk_widget_show (GnomeMeeting::Process ()->GetMainWindow ());
 }
 
 
 static void
 ekiga_assistant_cancel (GtkAssistant *gtkassistant)
 {
-  GtkWidget *main_window;
-
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-
-  gtk_widget_hide (GTK_WIDGET (gtkassistant));
   gtk_assistant_set_current_page (gtkassistant, 0);
-  gtk_widget_show (main_window);
+  gtk_widget_hide (GTK_WIDGET (gtkassistant));
+  gtk_widget_show (GnomeMeeting::Process ()->GetMainWindow ());
 }
 
 
@@ -1619,32 +1621,28 @@ ekiga_assistant_new (Ekiga::ServiceCore *core)
   assistant->priv->core = core;
 
   /* FIXME: move this into the caller */
-  g_signal_connect (assistant, "cancel",
-                    G_CALLBACK (gtk_widget_hide), NULL);
   g_signal_connect (assistant, "key-press-event",
                     G_CALLBACK (ekiga_assistant_key_press_cb), NULL);
 
-  sigc::connection conn;
-  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
-    = core->get ("videoinput-core");
-  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
-    = core->get ("audioinput-core");
-  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-    = core->get ("audiooutput-core");
+  boost::signals::connection conn;
+  assistant->priv->videoinput_core = core->get<Ekiga::VideoInputCore> ("videoinput-core");
+  assistant->priv->audioinput_core = core->get<Ekiga::AudioInputCore> ("audioinput-core");
+  assistant->priv->audiooutput_core = core->get<Ekiga::AudioOutputCore> ("audiooutput-core");
+  assistant->priv->bank = core->get<Opal::Bank> ("opal-account-store");
 
-  conn = videoinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_added_cb), assistant));
+  conn = assistant->priv->videoinput_core->device_added.connect (boost::bind (&on_videoinput_device_added_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
-  conn = videoinput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_removed_cb), assistant));
+  conn = assistant->priv->videoinput_core->device_removed.connect (boost::bind (&on_videoinput_device_removed_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
 
-  conn = audioinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_audioinput_device_added_cb), assistant));
+  conn = assistant->priv->audioinput_core->device_added.connect (boost::bind (&on_audioinput_device_added_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
-  conn = audioinput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audioinput_device_removed_cb), assistant));
+  conn =assistant->priv-> audioinput_core->device_removed.connect (boost::bind (&on_audioinput_device_removed_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
 
-  conn = audiooutput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_added_cb), assistant));
+  conn = assistant->priv->audiooutput_core->device_added.connect (boost::bind (&on_audiooutput_device_added_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
-  conn = audiooutput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_removed_cb), assistant));
+  conn = assistant->priv->audiooutput_core->device_removed.connect (boost::bind (&on_audiooutput_device_removed_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
 
   /* Notifiers for the VIDEO_CODECS_KEY keys */
