@@ -40,14 +40,12 @@
 #include "config.h"
 
 #include "callbacks.h"
-#include "main.h"
-#include "misc.h"
 
 #include "ekiga.h"
 
-#include "gmentrydialog.h"
 #include "gmconf.h"
 #include "gmdialog.h"
+#include "gmwindow.h"
 #include "gmconnectbutton.h"
 #include "gmmenuaddon.h"
 #include "gmstockicons.h"
@@ -63,63 +61,11 @@
 
 #undef GTK_DISABLE_DEPRECATED
 #ifdef HAVE_GNOME
-#include <gnome.h>
+#include <libgnome/gnome-help.h>
 #endif
 
 
 /* The callbacks */
-gboolean
-delete_window_cb (GtkWidget *widget,
-                  G_GNUC_UNUSED GdkEvent *event,
-                  G_GNUC_UNUSED gpointer data)
-{
-  gnomemeeting_window_hide (GTK_WIDGET (widget));
-
-  return TRUE;
-}
-
-static void
-show_window (GtkWidget *window)
-{
-  if (!gnomemeeting_window_is_visible (window))
-    gnomemeeting_window_show (window);
-  else
-    gtk_window_present (GTK_WINDOW (window));
-}
-
-void
-show_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-		gpointer data)
-{
-  show_window (GTK_WIDGET (data));
-}
-
-
-void
-show_assistant_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-                          G_GNUC_UNUSED gpointer data)
-{
-  GtkWidget *window = GnomeMeeting::Process ()->GetAssistantWindow ();
-  show_window (window);
-}
-
-void
-show_prefs_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-                      G_GNUC_UNUSED gpointer data)
-{
-  GtkWidget *window = GnomeMeeting::Process ()->GetPrefsWindow ();
-  show_window (window);
-}
-
-
-void
-hide_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-		gpointer data)
-{
-  if (gnomemeeting_window_is_visible (GTK_WIDGET (data)))
-    gnomemeeting_window_hide (GTK_WIDGET (data));
-}
-
 
 void
 about_callback (G_GNUC_UNUSED GtkWidget *widget, 
@@ -130,6 +76,7 @@ about_callback (G_GNUC_UNUSED GtkWidget *widget,
       "",
       N_("Contributors:"),
       "Howard Chu <hyc@symas.com>",
+      "Eugen Dedu <eugen.dedu@pu-pm.univ-fcomte.fr>",
       "Yannick Defais <sevmek@free.fr>",
       "Steve Fr\303\251cinaux <code@istique.net>",
       "Kilian Krause <kk@verfaction.de>", 
@@ -216,8 +163,8 @@ GNU GPL for all the rest of the software thus combined.")
 
 
 void
-help_cb (G_GNUC_UNUSED GtkWidget *widget,
-	 G_GNUC_UNUSED gpointer data)
+help_callback (G_GNUC_UNUSED GtkWidget *widget,
+	       G_GNUC_UNUSED gpointer data)
 {
 #ifdef WIN32
   gchar *locale, *loc_ , *index_path;
@@ -260,13 +207,8 @@ help_cb (G_GNUC_UNUSED GtkWidget *widget,
 
 #ifdef HAVE_GNOME
   success = gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
-#elif GTK_CHECK_VERSION(2, 13, 1)
-  success = gtk_show_uri (NULL, "ghelp:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
 #else
-  success = FALSE;
-  err = g_error_new_literal (g_quark_from_static_string ("ekiga"),
-                             0,
-			     _("Help display is not supported by your GTK+ version"));
+  success = gtk_show_uri (NULL, "ghelp:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
 #endif
 
   if (!success) {
@@ -295,16 +237,16 @@ quit_callback (G_GNUC_UNUSED GtkWidget *widget,
   GtkWidget *accounts_window = NULL;
 
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
-  assistant_window = GnomeMeeting::Process ()->GetAssistantWindow (false);
-  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow (false);
+  assistant_window = GnomeMeeting::Process ()->GetAssistantWindow ();
+  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow ();
   accounts_window = GnomeMeeting::Process ()->GetAccountsWindow ();
   
   gtk_widget_hide (main_window);
   if (assistant_window)
-    gnomemeeting_window_hide (assistant_window);
+    gm_window_hide (assistant_window);
   if (prefs_window)
-    gnomemeeting_window_hide (prefs_window);
-  gnomemeeting_window_hide (accounts_window);
+    gm_window_hide (prefs_window);
+  gm_window_hide (accounts_window);
 
   while (gtk_events_pending ())
     gtk_main_iteration ();
